depends = [
    "403 Forbidden",
    "404 ERROR",
    "404 File Not Found",
    "404 NOT FOUND",
    "404 Not Found",
    "404 Not Found.",
    "404 NotFound.",
    "404 Notfound（お探しのページは見つかりませんでした。）",
    "404 Page Not Found",
    "404 not found",
    "404 not found.",
    "404-Not Found",
    "404:ページが見つかりません",
    "404Not Found",
    "404エラー",
    "404：お探しのページは見つかりません。",
    "500 Internal Server Error",
    "502 Bad Gateway",
    "ERROR 404 - Page not found (ページが見つかりません)",
    "ERROR 404: ドキュメントが見つかりません",
    "File Not Found",
    "Forbidden",
    "Not Acceptable",
    "Not Found",
    "Not found.",
    "NotFound",
    "Oops! That page can’t be found.",
    "Page not found.",
    "The page you were looking for doesn't exist.",
    "Web ページが見つかりません。",
    "【404 NOT FOUND】 ご指定のページは見つかりませんでした",
    "【NOT FOUND】 ご指定のページは見つかりませんでした。",
    "お探しのコンテンツはみつかりませんでした。",
    "お探しのページ、またはファイルは見つかりませんでした。",
    "お探しのページが見つかりません",
    "お探しのページが見つかりません / NotFound",
    "お探しのページが見つかりません。",
    "お探しのページが見つかりませんでした",
    "お探しのページが見つかりませんでした。",
    "お探しのページが見つかりませんでした！",
    "お探しのページが見つかりません",
    "お探しのページは、更新中のため、表示することができませんでした。",
    "お探しのページはありません",
    "お探しのページはありません。",
    "お探しのページはありませんでした",
    "お探しのページはありません（404）",
    "お探しのページはみつかりません",
    "お探しのページはみつかりませんでした（404 Not Found）",
    "お探しのページは存在しません",
    "お探しのページは存在しません。",
    "お探しのページは移動した可能性があります",
    "お探しのページは移転もしくは削除されました。",
    "お探しのページは見つかりません",
    "お探しのページは見つかりません。",
    "お探しのページは見つかりません。 404 Not Found",
    "お探しのページは見つかりませんでした",
    "お探しのページは見つかりませんでした。",
    "お探しのページまたはファイルはありませんでした。",
    "お探しのページを見つけることができませんでした",
    "お探しのページを見つけることができませんでした。",
    "お探しのページを見つけることができませんでした。 404 - Not Found",
    "お探しのページ（URL）が見つかりませんでした",
    "お探しの記事は公開を終了しました。",
    "このページは存在していません。",
    "このページは存在しません",
    "このページを表示できません",
    "ご指定いただいたアドレスのページは存在しません。",
    "ご指定のページが見つかりません",
    "ご指定のページが見つかりません。",
    "ご指定のページが見つかりませんでした",
    "ご指定のページのアドレスは変更されているか、更新作業中です",
    "ご指定のページは見つかりませんでした",
    "ご指定のページは見つかりませんでした。",
    "ご指定のページは見つかりませんでした（404 Not Found）",
    "ご指定のページは見つかりませんでした｜404",
    "ご指定のページまたはファイルが見つかりませんでした",
    "ご指定のページまたはファイルが見つかりませんでした。",
    "ぺージが見つかりません",
    "ぺージが見つかりませんでした",
    "アクセスしたページはURL(アドレス)が変更となりました",
    "アクセスしようとしたページが見つかりません。",
    "アクセスしようとしたページは、サイト内に存在しません。",
    "アドレスを確認して、再度アクセスしてください。",
    "エラー",
    "エラー404 お探しのページは存在しません。",
    "エラーが発生しました",
    "エラーが発生しました。",
    "エラーページ",
    "コンテンツを表示することができません",
    "コンテンツを表示することができません。",
    "サーバー エラーが発生しました。（タイムアウトの可能性もあります）",
    "システムエラー",
    "ファイルが見つかりません",
    "ページがみつかりません",
    "ページがみつかりません - 404 Not Found -",
    "ページがみつかりませんでした",
    "ページが見つかりません",
    "ページが見つかりません Not Found",
    "ページが見つかりません （404 Not Found)",
    "ページが見つかりません。",
    "ページが見つかりません。Not Found",
    "ページが見つかりませんでした",
    "ページが見つかりませんでした。",
    "ページが見つかりませんでした（404エラー）",
    "ページを表示することができません",
    "ページを表示することができません。",
    "ページを表示できません",
    "ページエラーのお知らせ",
    "ホームページのリニューアルに伴うURLの変更",
    "ホームページをリニューアルしました",
    "変わりました。",
    "変わります",
    "変更された",
    "変更されました",
    "変更した",
    "変更します",
    "大変申し訳ございませんが、ご指定のコンテンツは見つかりませんでした。",
    "指定されたページ、またはファイルは見つかりませんでした。",
    "指定されたページが見つかりませんでした。",
    "指定されたページは存在しないか、公開を終了しています。(404エラー)",
    "指定されたページは存在しないか、公開を終了しています（404ERROR）",
    "指定されたページは存在しません。",
    "指定されたページは存在しませんでした",
    "指定されたページは見つかりませんでした。",
    "指定されたページまたはファイルは存在しません",
    "指定されたページ・ファイルは見つかりませんでした。",
    "指定のページは見つかりませんでした",
    "検索したページは見つかりませんでした",
    "現在接続されているページは、ページ移行されました。",
    "表示できません",
    "見つかりません",
    "見つかりません。",
    "見つかりませんでした。",
    "お探しのページが見つかりません-",
    "時的にご利用いただけません",
    "ホームページはリニューアルしました"
]