formats = [
    "関係法令の施行から2か月後（令和2年6月30日）、または猶予を受けようとする税目の納期限のいずれか遅い日まで。",
    "申請は納期限までとなります。",
    "原則として納期限が到来する７日前までに申請してください。",
    "太陽光受給契約確認書に記載された受給契約開始日から３ヶ月以内 です。 【 蓄電池 】 住宅用蓄電池システムを設置した方に、設置費用の一部を助成します。",
    "課税年度の初日の属する年の１月３１日までに、固定資産税課税免除申請書及び必要書類を提出してください。",
    "骨髄等の提供が完了してから 90日以内 申請場所 健康福祉課成人健康係窓口 必要書類 以下のとおり 骨髄等提供者（ドナー）",
    "申請期限は各期別の納期限と同日です。なお、 納期限を過ぎると減免の対象になりません。",
    "令和5年3月31日までに申請してください。",
    "検査を終了した日の属する年度末までに申請してください。",
    "は、8月11日（火曜日）までです。期限が迫っていますので、お早めに申請してください。8月12日以降は申請を受け付けることができなくなります。ご注意ください。",
    "対象品を購入した日（領収書に記載の日）の翌日から1年以内",
    "就労奨励金",
    "​損害を被った日の属する月の翌月初日から1年間",
    "学生納付特例を希望するとき（決定までは、3～4ヵ月程度かかります）。 ※学生納付特例を受けていた人で、引き続き学生納付特例を希望する場合は、毎年4月～5月中に、再度申請が必要です。",
    "出生日から３か月以内に保護者の方が申請手続きをしてください",
    "出生から3か月以内",
    "令和５ 年12月28日（必着）",
    "令和4年度分",
    "ドナーが骨髄等の採取に伴う入院をして退院した日の翌日、中止者にあっては中止日から起算して1年以内",
    "申請は、運転免許証を返納してから3か月以内に行ってください。",
    "申請年度の1月末迄 ※転入日によっては申請できなくなる場合が有りますので、要件を満たした場合は早めの相談をお願いします。",
    "保険税の減免を受ける場合は、納期限までに申請が必要です。 減免申請書等は以下のとおりです。郵送での申請をご希望する場合や、ご質問等は税務課国民健康保険税係までお願いします。",
    "お子さんの出生日の翌日から6カ月以内 その他 申請時点で大府市に居住されているか等を確認させていただく場合がありますのでご了承ください。。",
    "6月7日（水） 夕張太集落センター 378－5888 ５月15日(月)",
    "令和５年３月３１日（金）",
    "所管(国・県・市など) 問合せ(電話) ホームページ",
    "不妊治療費事業受診等証明書に記載された治療期間終了日後1年以内に申請してください。 期限を過ぎた場合、助成金の支給はできません。",
    "・令和４年１２月３１日（土）まで",
    "原則として、建物登記完了日の翌日から起算して2カ月以内",
    "1期 令和5年5月15日(月) ※締め切りました。",
    "令和2年2月1日から令和5年3月31日までに納期限が到来する保険税が減免の対象となります。",
    "減免を受けようとする納期限までに申請が必要 ３．申請に必要な書類 ア 申請する全ての方 ・個人市民税・県民税減免申請書 ・本人確認書類",
    "補助金交付申請期限",
    "令和4年8月4日（木曜日）当日消印有効",
    "手術日より3カ月以内 です。",
    "6月21日",
    "治療が終了した日の属する年度の3月31日まで。（ただし、2月～3月治療終了分は翌年度の4月最終開庁日まで）",
    "支給申請期限は2年となっています。",
    "令和6年3月31日まで",
    "平成29年10月31日（平成30年3月30日まで完了届を提出できること） ※秋田県の住宅リフォーム推進事業と併用ができます。",
    "令和5年度の申請は、 令和6年1月31日（水）まで です。 予算に限りがあるため、申請要件を満たしている場合はお早めにご相談ください。",
    "建物登記完了日または松田町に住民登録をした日のいずれか遅い日から ６カ月以内 に申請してください。",
    "補正具を購入した日から1年以内",
    "令和４年４月３０日（土曜日）消印有効 ※窓口での申請は令和４年４月２８日（木曜日）まで",
    "避妊・去勢手術日から3か月以内",
    "令和3年3月31日まで",
    "児童手当は、原則、申請した月の翌月分から支給されます。ただし、出生日や転出予定日（異動日）が月末に近い場合、申請が翌月になっても異動日の翌日から15日以内の申請であれば、申請月から支給します。申請が遅れると、遅れた月分の手当を受けられなくなることがありますので、ご注意ください。",
    "定期券購入日から３０日以内",
    "不妊治療費事業受診等証明書に記載された治療期間終了日後1年以内に申請してください。 期間を過ぎた場合、助成金の支給はできません。",
    "介護職員初任者研修修了日の翌日から1年以内",
    "・犯罪行為による死亡若しくは傷病の発生を知った日から２年以内又は死亡若しくは傷病が発生した日から７年以内",
    "令和5年3月15日まで",
    "令和5年8月31日（木曜日）まで",
    "令和3年度非課税世帯： 令和4年9月30日（金曜日）",
    "令和4年7月15日（金曜日）～令和5年5月31日（水曜日）必着",
    "購入後60日以内に申請してください。",
    "申請期限はありません。",
    "令和5年6月30日（消印有効）",
    "資格取得日または結果通知日から３カ月以内。 また、補助金交付額が予算額に到達した場合、その年度内の申請を打ち切ります。",
    "令和5年度当初の申請の場合、令和5年2月22日（水曜日）までに、申請書をお子さんの通学校または学校教育課に提出してください。"
]