formats = [
    "令和4年度分国民年金保険料免除申請（特例措置）→令和4年7月1日から受付開始",
    "令和4年（2022年）6月20日（月） ※先着順に受付し、予算額に達し次第、受付を終了します。 ※予算額には限りがありますので、申請をしても補助金の交付を受けられない",
    "福祉交流センター 2023年6月8日（木曜日）、2023年8月3日（木曜日） 午後1時～午後5時 2023年5月15日（月曜日）から",
    "令和2年5月1日",
    "(1)受付期限は令和５年6月30日までです。(受付時間は午前8時30分から午後5時15分) ※期限までに申請が難しい場所は市民課生活係までお気軽にご相談ください。",
    "・6月10日（金曜日）から受付を開始します。 なお、保険料の減免決定通知が届くまでは、保険料のご納付をお願します。 ※新型コロナウイルス感染症予防のため申請は郵送でも受付けをします。",
    "平成31年4月1日〜",
    "令和２年５月１日",
    "令和2年5月1日"
]